@@ -24,6 +24,8 @@
 #' @param partial_block argument fed into \code{tabulate_state_vector}, if the number of
 #' entries is not divisible by the \code{block_length}, this logical decides
 #' whether to keep the smaller last block (default \code{TRUE})
+#' @param na.rm whether to keep track of missing values as part of the analysis or
+#' ignore them (default \code{FALSE})
 #' @param min_var argument fed into \code{mc_adjust}, if a column in the state
 #' vector has variance less than this value, remove it (default 0.1)
 #' @param max_cor argument fed into \code{mc_adjust}, if a column in the state
@@ -52,9 +54,9 @@
 #' @export
 
 hmat <- function(data, input = "data", top = 20, order = "numeric", block_length = NULL,
-                 level_limit = 50, level_keep = 10, partial_block = TRUE, min_var = 0.1,
-                 max_cor = 0.9, action = "exclude", output = "both",
-                 normalize = FALSE) {
+                 level_limit = 50, level_keep = 10, partial_block = TRUE, na.rm = FALSE,
+                 min_var = 0.1, max_cor = 0.9, action = "exclude",
+                 output = "both", normalize = FALSE) {
 
   # if the input is a vector or NULL, throw a warning
   if (is.vector(data)) {
@@ -86,7 +88,8 @@ hmat <- function(data, input = "data", top = 20, order = "numeric", block_length
                   anomalyDetection::tabulate_state_vector(data,block_length,
                                                           level_limit,
                                                           level_keep,
-                                                          partial_block)
+                                                          partial_block,
+                                                          na.rm)
                 ,min_var, max_cor, action)
               ,output, normalize)
             )
